X509BundleSet

Struct X509BundleSet 

pub struct X509BundleSet { /* private fields */ }
Contains a set of X509Bundle, keyed by TrustDomain.

Implementations

Source

impl X509BundleSet

pub const fn new() -> Self

Creates a new empty X509BundleSet.

Examples
use spiffe::{TrustDomain, X509Bundle, X509BundleSet};

let mut set = X509BundleSet::new();
let trust_domain = TrustDomain::new("example.org")?;
let bundle = X509Bundle::new(trust_domain.clone());
set.add_bundle(bundle);
pub fn add_bundle(&mut self, bundle: X509Bundle)

Adds a new X509Bundle into the set. If a bundle already exists for the trust domain, the existing bundle is replaced.

pub fn get(&self, trust_domain: &TrustDomain) -> Option<Arc<X509Bundle>>

Returns the bundle for a trust domain.

Examples
use spiffe::{TrustDomain, X509Bundle, X509BundleSet};

let mut set = X509BundleSet::new();
let trust_domain = TrustDomain::new("example.org")?;
let bundle = X509Bundle::new(trust_domain.clone());
set.add_bundle(bundle);

let retrieved = set.get(&trust_domain);
assert!(retrieved.is_some());
pub fn get_ref(&self, trust_domain: &TrustDomain) -> Option<&Arc<X509Bundle>>

Returns a reference to the bundle for a trust domain.

pub fn iter(&self) -> impl Iterator<Item = (&TrustDomain, &Arc<X509Bundle>)>

Returns an iterator over (TrustDomain, X509Bundle) entries.

Examples
use spiffe::{TrustDomain, X509Bundle, X509BundleSet};

let mut set = X509BundleSet::new();
let td1 = TrustDomain::new("example.org")?;
let td2 = TrustDomain::new("other.org")?;
set.add_bundle(X509Bundle::new(td1.clone()));
set.add_bundle(X509Bundle::new(td2.clone()));

for (trust_domain, bundle) in set.iter() {
    println!("Bundle for {}: {} authorities", trust_domain, bundle.authorities().len());
}
pub fn len(&self) -> usize

Returns the number of bundles in the set.

pub fn is_empty(&self) -> bool

Returns true if the set contains no bundles.

pub fn bundle_for(&self, trust_domain: &TrustDomain) -> Option<&Arc<X509Bundle>>

👎Deprecated since 0.9.0:

Use X509BundleSet::get instead.

Returns the X509Bundle associated with the given TrustDomain.